@@ -11,7 +11,7 @@ from scrapy.exceptions import NotConfigured
 from scrapy.utils.trackref import live_refs
 
 
-class MemoryDebugger(object):
+class MemoryDebugger:
 
     def __init__(self, stats):
         self.stats = stats
