@@ -1,7 +1,8 @@
 """Some debugging functions for working with the Scrapy engine"""
 
-from __future__ import print_function
-from time import time # used in global tests code
+# used in global tests code
+from time import time  # noqa: F401
+
 
 def get_engine_status(engine):
     """Return a report of the current engine status"""
@@ -32,6 +33,7 @@ def get_engine_status(engine):
 
     return checks
 
+
 def format_engine_status(engine=None):
     checks = get_engine_status(engine)
     s = "Execution engine status\n\n"
@@ -41,5 +43,6 @@ def format_engine_status(engine=None):
 
     return s
 
+
 def print_engine_status(engine):
     print(format_engine_status(engine))
